@@ -15,7 +15,7 @@ DEFAULT_CONFIG_ENCODING = 'utf-8'
 RUNNING_AS_ROOT = os.geteuid() == 0
 
 
-VERSION = '1.11-dev'
+VERSION = '1.12-dev'
 
 _USER_CACHE_HOME = os.environ.get(
     "XDG_CACHE_HOME",
@@ -103,6 +103,10 @@ CONFIG_SCHEMA: Dict[str, Any] = {
             'type': 'bool',
             'default': 'no',
         },
+        'GpgDir': {
+            'type': 'str',
+            'default': ('/etc/pacman.d/gnupg/' if RUNNING_AS_ROOT else '')
+        },
         'SkipFailedBuild': {
             'type': 'bool',
             'default': 'no',
