@@ -19,7 +19,9 @@ import pyalpm
 from .args import parse_args
 from .config import PikaurConfig
 from .i18n import translate
-from .pprint import print_stderr, color_line, print_error, bold_line
+from .pprint import (
+    print_stderr, color_line, print_error, bold_line, ColorsHighlight,
+)
 
 if TYPE_CHECKING:
     # pylint: disable=cyclic-import
@@ -66,7 +68,7 @@ class ComparableType:
 
 class DataType(ComparableType):
 
-    @classmethod
+    @classmethod  # type: ignore[misc]
     @property
     def __all_annotations__(cls) -> Dict[str, Any]:
         annotations: Dict[str, Any] = {}
@@ -164,7 +166,7 @@ class InteractiveSpawn(subprocess.Popen):
         if parse_args().print_commands:
             if self.args != get_sudo_refresh_command():
                 print_stderr(
-                    color_line('=> ', 14) +
+                    color_line('=> ', ColorsHighlight.cyan) +
                     (
                         ' '.join(str(arg) for arg in self.args)
                         if isinstance(self.args, list) else
@@ -214,7 +216,7 @@ def running_as_root() -> bool:
     return os.geteuid() == 0
 
 
-def isolate_root_cmd(cmd: List[str], cwd=None) -> List[str]:
+def isolate_root_cmd(cmd: List[str], cwd=None, env=None) -> List[str]:
     if not running_as_root():
         return cmd
     base_root_isolator = [
@@ -225,6 +227,9 @@ def isolate_root_cmd(cmd: List[str], cwd=None) -> List[str]:
         '-p', 'CacheDirectory=pikaur',
         '-E', 'HOME=/tmp',
     ]
+    if env is not None:
+        for env_var_name, env_var_value in env.items():
+            base_root_isolator += ['-E', f'{env_var_name}={env_var_value}']
     if cwd is not None:
         base_root_isolator += ['-p', 'WorkingDirectory=' + os.path.abspath(cwd)]
     for env_var_name in (
