@@ -5,7 +5,7 @@ import os
 import hashlib
 from multiprocessing.pool import ThreadPool
 from tempfile import NamedTemporaryFile
-from typing import List, Dict, Optional, Set, Any
+from typing import List, Dict, Optional, Set
 
 import pyalpm
 
@@ -24,8 +24,8 @@ from .exceptions import (
 )
 from .build import PackageBuild, clone_aur_repos, PkgbuildChanged
 from .pprint import (
-    color_line, bold_line,
-    print_stderr, print_stdout, print_warning, print_error, print_debug,
+    color_line, bold_line, ColorsHighlight,
+    print_stderr, print_stdout, print_warning, print_error, create_debug_logger,
 )
 from .print_department import (
     pretty_format_sysupgrade,
@@ -34,7 +34,7 @@ from .print_department import (
 )
 from .core import (
     PackageSource,
-    interactive_spawn, remove_dir, open_file, sudo, running_as_root,
+    interactive_spawn, remove_dir, open_file, sudo, running_as_root, isolate_root_cmd
 )
 from .conflicts import find_aur_conflicts
 from .prompt import (
@@ -47,8 +47,7 @@ from .version import compare_versions
 from .updates import is_devel_pkg
 
 
-def debug(msg: Any) -> None:
-    print_debug(f"install_cli: {str(msg)}")
+_debug = create_debug_logger('install_cli')
 
 
 def hash_file(filename: str) -> str:  # pragma: no cover
@@ -84,6 +83,7 @@ class InstallPackagesCLI():
     # @TODO: define @property for manually_excluded_packages_names+args.ignore:
     manually_excluded_packages_names: List[str]
     resolved_conflicts: List[List[str]]
+    reviewed_package_bases: List[str]
     # pkgbuild_path: [pkg_name, ...]  -- needed for split pkgs to install only some of them
     pkgbuilds_packagelists: Dict[str, List[str]]
 
@@ -114,6 +114,7 @@ class InstallPackagesCLI():
         self.pkgbuilds_packagelists = {}
         self.manually_excluded_packages_names = []
         self.resolved_conflicts = []
+        self.reviewed_package_bases = []
 
         self.not_found_repo_pkgs_names = []
         self.repo_packages_by_name = {}
@@ -150,7 +151,7 @@ class InstallPackagesCLI():
 
         if self.args.sysupgrade and not self.args.repo:
             print_stderr('{} {}'.format(  # pylint: disable=consider-using-f-string
-                color_line('::', 12),
+                color_line('::', ColorsHighlight.blue),
                 bold_line(translate("Starting full AUR upgrade..."))
             ))
         if self.args.aur:
@@ -204,7 +205,7 @@ class InstallPackagesCLI():
 
     def aur_pkg_not_found_prompt(self, pkg_name: str) -> None:  # pragma: no cover
         prompt = '{} {}\n{}\n{}\n{}\n> '.format(  # pylint: disable=consider-using-f-string
-            color_line('::', 11),
+            color_line('::', ColorsHighlight.yellow),
             translate("Try recovering {pkg_name}?").format(pkg_name=bold_line(pkg_name)),
             translate("[e] edit PKGBUILD"),
             translate("[s] skip this package"),
@@ -268,7 +269,7 @@ class InstallPackagesCLI():
             print_not_found_packages(exc.packages)
             raise SysExit(131) from exc
         except DependencyVersionMismatch as exc:
-            print_stderr(color_line(translate("Version mismatch:"), 11))
+            print_stderr(color_line(translate("Version mismatch:"), ColorsHighlight.yellow))
             print_stderr(
                 translate("{what} depends on: '{dep}'\n found in '{location}': '{version}'").format(
                     what=bold_line(exc.who_depends),
@@ -293,7 +294,7 @@ class InstallPackagesCLI():
                     self.install_info.repo_packages_install_info +
                     self.install_info.new_repo_deps_install_info +
                     self.install_info.thirdparty_repo_packages_install_info +
-                    self.install_info.aur_updates_install_info  # type: ignore[operator]
+                    self.install_info.aur_updates_install_info
             ):
                 if (
                         # devel packages will be checked later
@@ -329,7 +330,7 @@ class InstallPackagesCLI():
                 self.install_repo_packages()
             else:
                 print_stdout('{} {}'.format(  # pylint: disable=consider-using-f-string
-                    color_line('::', 10),
+                    color_line('::', ColorsHighlight.green),
                     translate("Nothing to do."),
                 ))
             raise SysExit(0)
@@ -395,9 +396,9 @@ class InstallPackagesCLI():
         def _confirm_sysupgrade(verbose=False) -> str:
             _print_sysupgrade(verbose=verbose)
             prompt = '{} {}\n{} {}\n>> '.format(  # pylint: disable=consider-using-f-string
-                color_line('::', 12),
+                color_line('::', ColorsHighlight.blue),
                 bold_line(translate('Proceed with installation? [Y/n] ')),
-                color_line('::', 12),
+                color_line('::', ColorsHighlight.blue),
                 bold_line(translate('[v]iew package details   [m]anually select packages')))
 
             answer = get_input(
@@ -431,15 +432,15 @@ class InstallPackagesCLI():
             break
 
     def discard_install_info(self, canceled_pkg_name: str, ignore=True) -> None:
-        debug(f"discarding install info for pkg... {canceled_pkg_name}")
+        _debug(f"discarding install info for pkg... {canceled_pkg_name}")
         if ignore:
-            debug(f"ignoring pkg... {canceled_pkg_name}")
+            _debug(f"ignoring pkg... {canceled_pkg_name}")
             self.manually_excluded_packages_names.append(canceled_pkg_name)
         if not getattr(self, 'install_info', None):  # @TODO: make it nicer?
-            debug("install info not initialized yet -- running on early stage?")
+            _debug("install info not initialized yet -- running on early stage?")
             return
         for pkg_name in self.install_info.discard_package(canceled_pkg_name):
-            debug(f"discarded install info for pkg: {pkg_name}")
+            _debug(f"discarded install info for pkg: {pkg_name}")
             if pkg_name in self.install_package_names:
                 self.install_package_names.remove(pkg_name)
             if pkg_name in self.not_found_repo_pkgs_names:
@@ -534,7 +535,7 @@ class InstallPackagesCLI():
                         name=', '.join(package_build.package_names),
                         path=package_build.repo_path
                     ),
-                    9
+                    ColorsHighlight.red
                 ))
                 print_stderr(err.result.stdout_text)
                 print_stderr(err.result.stderr_text)
@@ -542,7 +543,7 @@ class InstallPackagesCLI():
                     answer = translate("a")
                 else:  # pragma: no cover
                     prompt = '{} {}\n> '.format(
-                        color_line('::', 11),
+                        color_line('::', ColorsHighlight.yellow),
                         '\n'.join((
                             translate("Try recovering?"),
                             translate("[c] git checkout -- '*'"),
@@ -589,7 +590,7 @@ class InstallPackagesCLI():
                     pkg_base = info.package.packagebase
                     if pkg_base not in pkgbuilds_by_base:
                         package_names = self.pkgbuilds_packagelists.get(info.pkgbuild_path)
-                        print_debug(
+                        _debug(
                             f"Initializing build info for {pkg_base=}, "
                             f"{info.pkgbuild_path=}, {package_names=}"
                         )
@@ -633,12 +634,12 @@ class InstallPackagesCLI():
                     print_stderr(color_line(
                         translate("New packages '{new}' and '{other}' are in conflict.").format(
                             new=new_pkg_name, other=pkg_conflict),
-                        9))
+                        ColorsHighlight.red))
                     raise SysExit(131)
         for new_pkg_name, new_pkg_conflicts in self.found_conflicts.items():
             for pkg_conflict in new_pkg_conflicts:
                 answer = ask_to_continue('{} {}'.format(  # pylint: disable=consider-using-f-string
-                    color_line('::', 11),
+                    color_line('::', ColorsHighlight.yellow),
                     bold_line(translate(
                         "{new} and {installed} are in conflict. Remove {installed}?"
                     ).format(
@@ -657,7 +658,7 @@ class InstallPackagesCLI():
         )
         if noedit or self.args.noconfirm:
             print_stderr('{} {}'.format(  # pylint: disable=consider-using-f-string
-                color_line('::', 11),
+                color_line('::', ColorsHighlight.yellow),
                 translate("Skipping review of {file} for {name} package ({flag})").format(
                     file=filename,
                     name=', '.join(package_build.package_names),
@@ -743,6 +744,15 @@ class InstallPackagesCLI():
             _pkg_label = bold_line(', '.join(pkg_build.package_names))
             _skip_diff_label = translate("Not showing diff for {pkg} package ({reason})")
 
+            if (
+                    pkg_build.package_base in self.reviewed_package_bases
+            ):
+                print_warning(_skip_diff_label.format(
+                    pkg=_pkg_label,
+                    reason=translate("already reviewed")
+                ))
+                continue
+
             if (
                     pkg_build.last_installed_hash != pkg_build.current_hash
             ) and (
@@ -781,7 +791,7 @@ class InstallPackagesCLI():
                             git_args += [
                                 f':(exclude){file_path}',
                             ]
-                    interactive_spawn(git_args)
+                    interactive_spawn(isolate_root_cmd(git_args))
             elif self.args.noconfirm:
                 print_stdout(_skip_diff_label.format(
                     pkg=_pkg_label,
@@ -814,9 +824,10 @@ class InstallPackagesCLI():
 
             pkg_build.check_pkg_arch()
             pkg_build.reviewed = True
+            self.reviewed_package_bases.append(pkg_build.package_base)
 
     def handle_pkgbuild_changed(self, pkg_build: PackageBuild) -> None:
-        debug(f'handle pkgbuild changed {pkg_build=}')
+        _debug(f'handle pkgbuild changed {pkg_build=}')
         for pkg_name in pkg_build.package_names:
             self.discard_install_info(pkg_name, ignore=False)
         src_info = SrcInfo(pkgbuild_path=pkg_build.pkgbuild_path)
@@ -825,9 +836,10 @@ class InstallPackagesCLI():
         new_srcinfo_hash = hash_file(src_info.path)
 
         self.pkgbuilds_packagelists[pkg_build.pkgbuild_path] = pkg_build.package_names
+        self.reviewed_package_bases.append(pkg_build.package_base)
 
         if not getattr(self, 'install_info', None):  # @TODO: make it nicer?
-            debug("install info not initialized yet -- running on early stage?")
+            _debug("install info not initialized yet -- running on early stage?")
             if old_srcinfo_hash != new_srcinfo_hash:
                 print_warning(translate(
                     "Installation info changed (or new deps found) for {pkg} package"
@@ -862,7 +874,7 @@ class InstallPackagesCLI():
         packages_to_be_built = self.all_aur_packages_names[:]
         index = 0
         while packages_to_be_built:
-            print_debug(f"Gonna build {self.package_builds_by_name=}")
+            _debug(f"Gonna build {self.package_builds_by_name=}")
             if index >= len(packages_to_be_built):
                 index = 0
 
@@ -873,7 +885,7 @@ class InstallPackagesCLI():
                 continue
 
             try:
-                print_debug(f"Gonna build {pkg_build.package_names=}")
+                _debug(f"Gonna build {pkg_build.package_names=}")
                 pkg_build.build(
                     all_package_builds=self.package_builds_by_name,
                     resolved_conflicts=self.resolved_conflicts
@@ -883,7 +895,10 @@ class InstallPackagesCLI():
             except (BuildError, DependencyError) as exc:
                 print_stderr(exc)
                 print_stderr(
-                    color_line(translate("Can't build '{name}'.").format(name=pkg_name) + '\n', 9)
+                    color_line(
+                        translate("Can't build '{name}'.").format(name=pkg_name) + '\n',
+                        ColorsHighlight.red
+                    )
                 )
                 # if not ask_to_continue():
                 #     raise SysExit(125)
@@ -908,7 +923,7 @@ class InstallPackagesCLI():
                         )
                         raise SysExit(131) from exc
             else:
-                print_debug(
+                _debug(
                     f"Build done for packages {pkg_build.package_names=}, removing from queue"
                 )
                 for _pkg_name in pkg_build.package_names:
@@ -1066,7 +1081,11 @@ class InstallPackagesCLI():
 
         if self.failed_to_build_package_names:
             print_stderr('\n'.join(
-                [color_line(translate("Failed to build following packages:"), 9), ] +
-                self.failed_to_build_package_names
+                [
+                    color_line(
+                        translate("Failed to build following packages:"),
+                        ColorsHighlight.red
+                    ),
+                ] + self.failed_to_build_package_names
             ))
             raise SysExit(1)
