@@ -10,8 +10,8 @@ from .config import PikaurConfig
 from .core import interactive_spawn, get_editor
 from .i18n import translate
 from .pprint import (
-    color_line, get_term_width, range_printable,
-    PrintLock, print_stderr, print_warning, print_debug,
+    color_line, get_term_width, range_printable, ColorsHighlight,
+    PrintLock, print_stderr, print_warning, create_debug_logger,
 )
 from .exceptions import SysExit
 from .pikspect import pikspect as pikspect_spawn
@@ -24,6 +24,9 @@ N = translate('n')
 Y_UP = Y.upper()
 N_UP = N.upper()
 
+_debug = create_debug_logger('prompt')
+_debug_nolock = create_debug_logger('prompt_nolock', lock=False)
+
 
 def read_answer_from_tty(question: str, answers: Sequence[str] = (Y_UP, N, )) -> str:
     '''
@@ -84,15 +87,6 @@ def split_last_line(text: str) -> str:
     return '\n'.join(prev_lines + [last_line])
 
 
-def _debug(message, *args, **kwargs):
-    nice_message = f'PROMPT: {message}'
-    print_debug(nice_message, *args, **kwargs)
-
-
-def _debug_nolock(*args):
-    _debug(*args, lock=False)
-
-
 def get_input(
         prompt: str, answers: Sequence[str] = (), require_confirm=False
 ) -> str:
@@ -101,7 +95,7 @@ def get_input(
     with PrintLock():
         with TTYInputWrapper():
 
-            if not(
+            if not (
                     require_confirm or PikaurConfig().ui.RequireEnterConfirm.get_bool()
             ):
                 _debug_nolock('Using custom input reader...')
@@ -195,9 +189,12 @@ def retry_interactive_command(
             good = interactive_spawn(cmd_args, **kwargs).returncode == 0
         if good:
             return good
-        print_stderr(color_line(translate("Command '{}' failed to execute.").format(
-            ' '.join(cmd_args)
-        ), 9))
+        print_stderr(color_line(
+            translate("Command '{}' failed to execute.").format(
+                ' '.join(cmd_args)
+            ),
+            ColorsHighlight.red
+        ))
         if not ask_to_continue(
                 text=translate("Do you want to retry?"),
                 default_yes=not args.noconfirm
