@@ -5,19 +5,23 @@ from typing import List, Tuple, Optional, Union
 
 import pyalpm
 
-from .i18n import translate_many
+from .i18n import translate, translate_many
 from .version import compare_versions
 from .pacman import (
-    PackageDB,
+    PackageDB, PacmanConfig,
     find_packages_not_from_repo, find_upgradeable_packages,
+    get_ignored_pkgnames_from_patterns,
 )
 from .aur import AURPackageInfo, find_aur_packages
-from .pprint import print_stderr
+from .pprint import print_stderr, print_stdout
 from .args import parse_args
 from .config import PikaurConfig
-from .core import AURInstallInfo, RepoInstallInfo
+from .core import AURInstallInfo, RepoInstallInfo, InstallInfo
 from .exceptions import PackagesNotFoundInRepo
-from .print_department import print_ignoring_outofdate_upgrade
+from .print_department import (
+    print_ignoring_outofdate_upgrade, print_ignored_package,
+    pretty_format_upgradeable,
+)
 
 
 DEVEL_PKGS_POSTFIXES = (
@@ -150,3 +154,43 @@ def find_aur_updates() -> Tuple[List[AURInstallInfo], List[str]]:
                 package_ttl_days=devel_packages_expiration
             )
     return aur_updates, not_found_aur_pkgs
+
+
+def print_upgradeable(ignored_only=False) -> None:
+    args = parse_args()
+    updates: List[InstallInfo] = []
+    if not args.repo:
+        aur_updates, _not_found_aur_pkgs = find_aur_updates()
+        updates += aur_updates
+    if not args.aur:
+        updates += find_repo_upgradeable()
+    if not updates:
+        return
+    pkg_names = [pkg.name for pkg in updates]
+    manually_ignored_pkg_names = get_ignored_pkgnames_from_patterns(
+        pkg_names,
+        args.ignore
+    )
+    config_ignored_pkg_names = get_ignored_pkgnames_from_patterns(
+        pkg_names,
+        PacmanConfig().options.get('IgnorePkg', [])
+    )
+    ignored_pkg_names = manually_ignored_pkg_names + config_ignored_pkg_names
+    for pkg in updates[:]:
+        if pkg.name in ignored_pkg_names:
+            updates.remove(pkg)
+            ignored_from = None
+            if pkg.name in config_ignored_pkg_names:
+                ignored_from = translate("(ignored in Pacman config)")
+            print_ignored_package(install_info=pkg, ignored_from=ignored_from)
+    if ignored_only:
+        return
+    if args.quiet:
+        print_stdout('\n'.join([
+            pkg_update.name for pkg_update in updates
+        ]))
+    else:
+        print_stdout(pretty_format_upgradeable(
+            updates,
+            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
+        ))
